asr.test.mocks.gpaw.calculator
==============================

.. automodule:: asr.test.mocks.gpaw.calculator

   
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: ASRCalculator
      :members:
   .. autoclass:: DOSCalculator
      :members:
   .. autoclass:: Occupations
      :members:
   .. autoclass:: Parameters
      :members:
   .. autoclass:: Setups
      :members:
   .. autoclass:: WaveFunctions
      :members:
   
   

   
   
   